@@ -2,21 +2,24 @@
 /*!	\file action.h
 **	\brief Template File
 **
-**	$Id$
-**
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2008 Chris Moore
 **
-**	This package is free software; you can redistribute it and/or
-**	modify it under the terms of the GNU General Public License as
-**	published by the Free Software Foundation; either version 2 of
-**	the License, or (at your option) any later version.
+**	This file is part of Synfig.
 **
-**	This package is distributed in the hope that it will be useful,
+**	Synfig is free software: you can redistribute it and/or modify
+**	it under the terms of the GNU General Public License as published by
+**	the Free Software Foundation, either version 2 of the License, or
+**	(at your option) any later version.
+**
+**	Synfig is distributed in the hope that it will be useful,
 **	but WITHOUT ANY WARRANTY; without even the implied warranty of
-**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-**	General Public License for more details.
+**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+**	GNU General Public License for more details.
+**
+**	You should have received a copy of the GNU General Public License
+**	along with Synfig.  If not, see <https://www.gnu.org/licenses/>.
 **	\endlegal
 */
 /* ========================================================================= */
@@ -108,7 +111,7 @@ public:
 	{
 		va_list args;
 		va_start(args,format);
-		desc_=etl::vstrprintf(format,args);
+		desc_=synfig::vstrprintf(format,args);
 		va_end(args);
 	}
 
@@ -117,7 +120,7 @@ public:
 	{
 		va_list args;
 		va_start(args,format);
-		desc_=etl::vstrprintf(format,args);
+		desc_=synfig::vstrprintf(format,args);
 		va_end(args);
 	}
 
@@ -228,8 +231,8 @@ public:
 	bool is_active()const { return active_; }
 
 #ifdef _DEBUG
-	virtual void ref()const;
-	virtual bool unref()const;
+	virtual void ref() const noexcept;
+	virtual void unref()const;
 #endif
 }; // END of class Action::Undoable
 
